@@ -1,4 +1,5 @@
 from .resources.community import CommunityResource
+from .resources.subgroup import SubgroupResource
 from .version import __version__
 from .requestor import Requestor
 
@@ -10,6 +11,7 @@ class ApiClient(object):
         self._timeout = timeout
         self._requestor = Requestor(api_url=self._api_url, api_key=self._api_key, timeout=self._timeout)
         self._community = CommunityResource(api_url=self._api_url, requestor=self._requestor)
+        self._subgroup = SubgroupResource(api_url=self._api_url, requestor=self._requestor)
 
     @property
     def version(self) -> str:
@@ -31,5 +33,9 @@ class ApiClient(object):
     def community(self) -> CommunityResource:
         return self._community
 
+    @property
+    def subgroup(self) -> SubgroupResource:
+        return self._subgroup
+
     def __str__(self) -> str:
         return f"{self._api_url}"
